@@ -3,10 +3,10 @@ package WebService::PayPal::NVP;
 use Moo;
 use DateTime;
 use LWP::UserAgent ();
-use URI::Escape qw/uri_escape uri_unescape/;
+use URI::Escape qw/uri_escape uri_escape_utf8 uri_unescape/;
 use WebService::PayPal::NVP::Response;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 has 'errors' => (
     is => 'rw',
@@ -122,7 +122,7 @@ sub _build_content {
     for my $key (keys %$args) {
         $args->{$key} = defined $args->{$key} ? $args->{$key} : '';
         push @args,
-            uc(uri_escape($key)) . '=' . uri_escape($args->{$key});
+            uc(uri_escape($key)) . '=' . uri_escape_utf8($args->{$key});
     }
 
     return (join '&', @args) || '';
@@ -152,6 +152,30 @@ sub do_direct_payment {
     $self->_do_request($args);
 }
 
+sub create_recurring_payments_profile {
+    my ($self, $args) = @_;
+    $args->{method} = 'CreateRecurringPaymentsProfile';
+    $self->_do_request($args);
+}
+
+sub manage_recurring_payments_profile_status {
+    my ($self, $args) = @_;
+    $args->{method} = 'ManageRecurringPaymentsProfileStatus';
+    $self->_do_request($args);
+}
+
+sub mass_pay {
+    my ($self, $args) = @_;
+    $args->{method} = 'MassPay';
+    $self->_do_request($args);
+}
+
+sub refund_transaction {
+    my ($self, $args) = @_;
+    $args->{method} = 'RefundTransaction';
+    $self->_do_request($args);
+}
+
 1;
 __END__
 
@@ -162,13 +186,13 @@ WebService::PayPal::NVP - PayPal NVP API
 =head1 DESCRIPTION
 
 A pure object oriented interface to PayPal's NVP API (Name-Value Pair). A lot of the logic in this module was taken from L<Business::PayPal::NVP>. I re-wrote it because it wasn't working with Catalyst adaptors and I couldn't save instances of it in Moose-type accessors. Otherwise it worked fine. So if you don't need that kind of support you should visit L<Business::PayPal::NVP>!.
-Currently supports C<do_direct_payment>, C<do_express_checkout_payment>, C<get_express_checkout_details> and C<set_express_checkout>. Another difference with this module compared to L<Business::PayPal::NVP> is that the keys may be passed as lowercase. Also, a response will return a WebService::PayPal::NVP::Response object where the response values are methods. Timestamps will automatically be converted to DateTime objects for your convenience.
+Another difference with this module compared to Business::PayPal::NVP is that the keys may be passed as lowercase. Also, a response will return a WebService::PayPal::NVP::Response object where the response values are methods. Timestamps will automatically be converted to DateTime objects for your convenience.
 
 
 =head1 SYNTAX
 
     my $nvp = WebService::PayPal::NVP->new(
-        user   => 'user.tld'
+        user   => 'user.tld',
         pwd    => 'xxx',
         sig    => 'xxxxxxx',
         branch => 'sandbox',
@@ -180,7 +204,7 @@ Currently supports C<do_direct_payment>, C<do_express_checkout_payment>, C<get_e
         CURRENCYCODE      => 'GBP',
         PAYMENTACTION     => 'Sale',
         RETURNURL         => "http://returnurl.tld",
-        CANCELURL         => 'http//cancelurl.tld",
+        CANCELURL         => "http//cancelurl.tld",
         LANDINGPAGE       => 'Login',
         ADDOVERRIDE       => 1,
         SHIPTONAME        => "Customer Name",
@@ -218,6 +242,36 @@ Currently supports C<do_direct_payment>, C<do_express_checkout_payment>, C<get_e
           for @{$res->errors};
     }
 
+=head1 METHODS
+
+=head2 create_recurring_payments_profile( $HashRef )
+
+=head2 do_direct_payment( $HashRef )
+
+=head2 do_express_checkout_payment( $HashRef )
+
+=head2 get_express_checkout_details( $HashRef )
+
+=head2 manage_recurring_payments_profile_status( $HashRef )
+
+=head2 mass_pay( $HashRef )
+
+=head2 refund_transaction( $HashRef )
+
+=head2 set_express_checkout( $HashRef )
+
+=head1 TESTING
+
+The main test will not work out of the box, because obviously it needs some sandbox/live api details before it can proceed. Simply create an C<auth.yml> file in the distribution directory with the following details:
+
+    ---
+    user: 'api_user'
+    pass: 'api password'
+    sig:  'api signature'
+    branch: 'sandbox or live'
+
+If it detects the file missing completely it will just skip every test. Otherwise, it will only fail if any of the required information is missing.
+
 =head1 AUTHOR
 
 Brad Haywood <brad@geeksware.com>
